import pytest
import tempfile
from pathlib import Path
import numpy as np
from PIL import Image
from PIL.PngImagePlugin import PngInfo
from src.a_gis import purify_image

def save_blank_file(path):
    img = np.zeros([100,100,3],dtype=np.uint8)
    img.fill(255) # numpy array!
    im = Image.fromarray(img) #convert numpy array to image
    metadata = PngInfo()
    metadata.add_text("MyNewString", "A string")
    metadata.add_text("MyNewInt", str(1234))
    im.save(path,pnginfo=metadata)

def test_remove_metadata():
    """ Test that metadata is removed by purify method. """

    with tempfile.TemporaryDirectory() as tmpdirname:
        print('created temporary directory', tmpdirname)
        path = Path(tmpdirname)/'blank.png'    
        save_blank_file(path)
           
        im = Image.open(path)
        print(im.info)
        assert im.info != {}

        im = purify_image(im)
        print(im.info)
        assert im.info == {}





def purify_image(existing):
    """Canonicalize an image for use in AEGIS.
    
    This should remove all metadata and superfluous information,
    except the actual image data. A purified image will always
    return the same content hash.
    """
    from PIL import Image

    # Create new empty image, same size and mode
    stripped = Image.new(existing.mode, existing.size)

    # Copy pixels, but not metadata, across
    stripped.putdata(existing.getdata())

    # Copy palette across, if any
    if 'P' in existing.mode: stripped.putpalette(existing.getpalette())
    
    return stripped




import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='a_gis',
    author='AEGIS 001',
    author_email='a-gis-001@proton.me',
    description='AEGIS',
    keywords='art, AI',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/a-gis-001/a_gis',
    project_urls={
        'Documentation': 'https://github.com/a-gis-001/a_gis',
        'Bug Reports':
        'https://github.com/a-gis-001/a_gis/issues',
        'Source Code': 'https://github.com/a-gis-001/a_gis',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 1 - Planning',
        
        'Intended Audience :: Developers',
        'Topic :: Scientific/Engineering :: Image Processing',

        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: The Unlicense (Unlicense)',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.9',
    install_requires=['pillow','numpy','pytest'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=a_gis:main',
    # You can execute `run` in bash to run `main()` in src/a_gis/__init__.py
    #     ],
    # },
)
